@@ -3,8 +3,7 @@ import json
 from flask import Blueprint, abort, request, Response
 
 from platypush.backend.http.app import template_folder
-from platypush.backend.http.app.utils import authenticate, logger, send_message
-
+from platypush.backend.http.app.utils import logger, send_message
 from platypush.message.event.http.hook import WebhookEvent
 
 
@@ -17,7 +16,6 @@ __routes__ = [
 
 
 @hook.route('/hook/<hook_name>', methods=['GET', 'POST', 'PUT', 'DELETE', 'PATCH', 'OPTIONS'])
-@authenticate(skip_auth_methods=['session'])
 def _hook(hook_name):
     """ Endpoint for custom webhooks """
 
@@ -26,6 +24,7 @@ def _hook(hook_name):
         'method': request.method,
         'args': dict(request.args or {}),
         'data': request.data.decode(),
+        'headers': dict(request.headers or {}),
     }
 
     if event_args['data']:
