@@ -1,5 +1,4 @@
 import enum
-import json
 import logging
 import re
 from functools import wraps
@@ -345,7 +344,7 @@ class WhileProcedure(LoopProcedure):
                         context[k] = eval('"{}"'.format(re.sub(r'(^|[^\\])"', '\1\\"', v)))
                     except Exception as e:
                         logger.warning('Could not parse value for context variable {}={}'.format(k, v))
-                        logger.warning('Context: {}'.format(json.dumps(context)))
+                        logger.warning('Context: {}'.format(context))
                         logger.exception(e)
 
         return context
@@ -460,7 +459,7 @@ class IfProcedure(Procedure):
                         exec('{}="{}"'.format(k, re.sub(r'(^|[^\\])"', '\1\\"', v)))
                     except Exception as e:
                         logger.warning('Could not set context variable {}={}'.format(k, v))
-                        logger.warning('Context: {}'.format(json.dumps(context)))
+                        logger.warning('Context: {}'.format(context))
                         logger.exception(e)
 
         condition_true = eval(self.condition)
